@@ -31,6 +31,7 @@ catch (ex) {
     }
     catch (ex) { }
 }
+treectl.onscroll();
 
 
 function up2k_flagbus() {
@@ -131,6 +132,283 @@ function up2k_flagbus() {
     return flag;
 }
 
+
+function U2pvis(act, btns) {
+    this.act = act;
+    this.ctr = { "ok": 0, "ng": 0, "bz": 0, "q": 0 };
+    this.tab = [];
+    this.head = 0;
+    this.tail = -1;
+    this.wsz = 3;
+
+    this.addfile = function (entry, sz) {
+        this.tab.push({
+            "hn": entry[0],
+            "ht": entry[1],
+            "hp": entry[2],
+            "in": 'q',
+            "nh": 0, //hashed
+            "nd": 0, //done
+            "cb": [], // bytes done in chunk
+            "bt": sz, // bytes total
+            "bd": 0,  // bytes done
+            "bd0": 0  // upload start
+        });
+        this.ctr["q"]++;
+        this.drawcard("q");
+        if (this.act == "q") {
+            this.addrow(this.tab.length - 1);
+        }
+        if (this.act == "bz") {
+            this.bzw();
+        }
+    };
+
+    this.is_act = function (card) {
+        if (this.act == "done")
+            return card == "ok" || card == "ng";
+
+        return this.act == card;
+    }
+
+    this.seth = function (nfile, field, html) {
+        var fo = this.tab[nfile];
+        field = ['hn', 'ht', 'hp'][field];
+        if (fo[field] === html)
+            return;
+
+        fo[field] = html;
+        if (!this.is_act(fo.in))
+            return;
+
+        var obj = ebi('f{0}{1}'.format(nfile, field.slice(1)));
+        obj.innerHTML = html;
+        if (field == 'hp') {
+            obj.style.color = '';
+            obj.style.background = '';
+        }
+    };
+
+    this.setab = function (nfile, nblocks) {
+        var t = [];
+        for (var a = 0; a < nblocks; a++)
+            t.push(0);
+
+        this.tab[nfile].cb = t;
+    };
+
+    this.setat = function (nfile, blocktab) {
+        this.tab[nfile].cb = blocktab;
+
+        var bd = 0;
+        for (var a = 0; a < blocktab.length; a++)
+            bd += blocktab[a];
+
+        this.tab[nfile].bd = bd;
+        this.tab[nfile].bd0 = bd;
+    };
+
+    this.perc = function (bd, bd0, sz, t0) {
+        var td = new Date().getTime() - t0,
+            p = bd * 100.0 / sz,
+            nb = bd - bd0,
+            spd = nb / (td / 1000),
+            eta = (sz - bd) / spd;
+
+        return [p, s2ms(eta), spd / (1024 * 1024)];
+    };
+
+    this.hashed = function (fobj) {
+        var fo = this.tab[fobj.n];
+        var nb = fo.bt * (++fo.nh / fo.cb.length);
+        var p = this.perc(nb, 0, fobj.size, fobj.t1);
+        fo.hp = '{0}%, {1}, {2} MB/s'.format(
+            p[0].toFixed(2), p[1], p[2].toFixed(2)
+        );
+        if (!this.is_act(fo.in))
+            return;
+
+        var obj = ebi('f{0}p'.format(fobj.n));
+        obj.innerHTML = fo.hp;
+        obj.style.color = '#fff';
+        var o1 = p[0] - 2, o2 = p[0] - 0.1, o3 = p[0];
+        obj.style.background = 'linear-gradient(90deg, #025, #06a ' + o1 + '%, #09d ' + o2 + '%, #333 ' + o3 + '%, #333 99%, #777)';
+    };
+
+    this.prog = function (fobj, nchunk, cbd) {
+        var fo = this.tab[fobj.n];
+        var delta = cbd - fo.cb[nchunk];
+        fo.cb[nchunk] = cbd;
+        fo.bd += delta;
+
+        var p = this.perc(fo.bd, fo.bd0, fo.bt, fobj.t3);
+        fo.hp = '{0}%, {1}, {2} MB/s'.format(
+            p[0].toFixed(2), p[1], p[2].toFixed(2)
+        );
+
+        if (!this.is_act(fo.in))
+            return;
+
+        var obj = ebi('f{0}p'.format(fobj.n));
+        obj.innerHTML = fo.hp;
+        obj.style.color = '#fff';
+        var o1 = p[0] - 2, o2 = p[0] - 0.1, o3 = p[0];
+        obj.style.background = 'linear-gradient(90deg, #050, #270 ' + o1 + '%, #4b0 ' + o2 + '%, #333 ' + o3 + '%, #333 99%, #777)';
+    };
+
+    this.move = function (nfile, newcat) {
+        var fo = this.tab[nfile],
+            oldcat = fo.in,
+            bz_act = this.act == "bz";
+
+        if (oldcat == newcat) {
+            throw 42;
+        }
+
+        fo.in = newcat;
+        this.ctr[oldcat]--;
+        this.ctr[newcat]++;
+        this.drawcard(oldcat);
+        this.drawcard(newcat);
+        if (this.is_act(newcat)) {
+            this.tail++;
+            if (!ebi('f' + nfile))
+                this.addrow(nfile);
+        }
+        else if (this.is_act(oldcat)) {
+            this.head++;
+            if (!bz_act) {
+                var tr = ebi("f" + nfile);
+                tr.parentNode.removeChild(tr);
+            }
+        }
+        if (bz_act) {
+            this.bzw();
+        }
+    };
+
+    this.bzw_log = function (first, last) {
+        console.log("first %d   head %d   tail %d   last %d", first, this.head, this.tail, last);
+        var trs = document.querySelectorAll('#u2tab>tbody>tr'), msg = [];
+        for (var a = 0; a < trs.length; a++)
+            msg.push(trs[a].getAttribute('id'));
+
+        console.log(msg.join(' '));
+    }
+
+    this.bzw = function () {
+        var first = document.querySelector('#u2tab>tbody>tr:first-child');
+        if (!first)
+            return;
+
+        var last = document.querySelector('#u2tab>tbody>tr:last-child');
+        first = parseInt(first.getAttribute('id').slice(1));
+        last = parseInt(last.getAttribute('id').slice(1));
+        //this.bzw_log(first, last);
+
+        while (this.head - first > this.wsz) {
+            var obj = ebi('f' + (first++));
+            obj.parentNode.removeChild(obj);
+        }
+        while (last - this.tail < this.wsz && last < this.tab.length - 2) {
+            var obj = ebi('f' + (++last));
+            if (!obj)
+                this.addrow(last);
+        }
+        //this.bzw_log(first, last);
+        //console.log('--');
+    };
+
+    this.drawcard = function (cat) {
+        var cards = document.querySelectorAll('#u2cards>a>span');
+
+        if (cat == "q") {
+            cards[4].innerHTML = this.ctr[cat];
+            return;
+        }
+        if (cat == "bz") {
+            cards[3].innerHTML = this.ctr[cat];
+            return;
+        }
+
+        cards[2].innerHTML = this.ctr["ok"] + this.ctr["ng"];
+
+        if (cat == "ng") {
+            cards[1].innerHTML = this.ctr[cat];
+        }
+        if (cat == "ok") {
+            cards[0].innerHTML = this.ctr[cat];
+        }
+    };
+
+    this.changecard = function (card) {
+        this.act = card;
+        var html = [];
+        this.head = -1;
+        this.tail = -1;
+        for (var a = 0; a < this.tab.length; a++) {
+            var rt = this.tab[a].in;
+            if (this.is_act(rt)) {
+                html.push(this.genrow(a, true));
+
+                this.tail = a;
+                if (this.head == -1)
+                    this.head = a;
+            }
+        }
+        if (this.head == -1) {
+            this.head = this.tab.length;
+            this.tail = this.head - 1;
+        }
+        if (card == "bz") {
+            for (var a = this.head - 1; a >= this.head - this.wsz && a >= 0; a--) {
+                html.unshift(this.genrow(a, true).replace(/><td>/, "><td>a "));
+            }
+            for (var a = this.tail + 1; a <= this.tail + this.wsz && a < this.tab.length; a++) {
+                html.push(this.genrow(a, true).replace(/><td>/, "><td>b "));
+            }
+        }
+        ebi('u2tab').tBodies[0].innerHTML = html.join('\n');
+    };
+
+    this.genrow = function (nfile, as_html) {
+        var r = this.tab[nfile],
+            td1 = '<td id="f' + nfile,
+            td = '</td>' + td1,
+            ret = td1 + 'n">' + r.hn +
+                td + 't">' + r.ht +
+                td + 'p" class="prog">' + r.hp + '</td>';
+
+        if (as_html)
+            return '<tr id="f' + nfile + '">' + ret + '</tr>';
+
+        var obj = document.createElement('tr');
+        obj.setAttribute('id', 'f' + nfile);
+        obj.innerHTML = ret;
+        return obj;
+    };
+
+    this.addrow = function (nfile) {
+        var tr = this.genrow(nfile);
+        ebi('u2tab').tBodies[0].appendChild(tr);
+    };
+
+    var that = this;
+    btns = document.querySelectorAll(btns + '>a[act]');
+    for (var a = 0; a < btns.length; a++) {
+        btns[a].onclick = function (e) {
+            ev(e);
+            var newtab = this.getAttribute('act');
+            for (var b = 0; b < btns.length; b++) {
+                btns[b].className = (
+                    btns[b].getAttribute('act') == newtab) ? 'act' : '';
+            }
+            that.changecard(newtab);
+        };
+    }
+}
+
+
 function up2k_init(have_crypto) {
     //have_crypto = false;
     var need_filereader_cache = undefined;
@@ -215,10 +493,6 @@ function up2k_init(have_crypto) {
     var flag_en = bcfg_get('flag_en', false);
     var fsearch = bcfg_get('fsearch', false);
 
-    var col_hashing = '#00bbff';
-    var col_hashed = '#004466';
-    var col_uploading = '#ffcc44';
-    var col_uploaded = '#00bb00';
     var fdom_ctr = 0;
     var st = {
         "files": [],
@@ -238,6 +512,8 @@ function up2k_init(have_crypto) {
         }
     };
 
+    var pvis = new U2pvis("bz", '#u2cards');
+
     var bobslice = null;
     if (window.File)
         bobslice = File.prototype.slice || File.prototype.mozSlice || File.prototype.webkitSlice;
@@ -374,7 +650,7 @@ function up2k_init(have_crypto) {
             for (var a = 0, aa = Math.min(20, bad_files.length); a < aa; a++)
                 msg += '-- ' + bad_files[a] + '\n';
 
-            if (files.length - bad_files.length <= 1 && /(android)/i.test(navigator.userAgent))
+            if (good_files.length - bad_files.length <= 1 && /(android)/i.test(navigator.userAgent))
                 msg += '\nFirefox-Android has a bug which prevents selecting multiple files. Try selecting one file at a time. For more info, see firefox bug 1456557';
 
             alert(msg);
@@ -412,11 +688,12 @@ function up2k_init(have_crypto) {
             if (skip)
                 continue;
 
-            var tr = document.createElement('tr');
-            tr.innerHTML = '<td id="f{0}n"></td><td id="f{0}t">hashing</td><td id="f{0}p" class="prog"></td>'.format(st.files.length);
-            tr.getElementsByTagName('td')[0].innerHTML = fsearch ? entry.name : linksplit(esc(entry.purl + entry.name)).join(' ');
-            ebi('u2tab').appendChild(tr);
-
+            pvis.addfile([
+                fsearch ? esc(entry.name) : linksplit(
+                    esc(uricom_dec(entry.purl)[0] + entry.name)).join(' '),
+                '📐 hash',
+                ''
+            ], fobj.size);
             st.files.push(entry);
             st.todo.hash.push(entry);
         }
@@ -437,7 +714,10 @@ function up2k_init(have_crypto) {
         for (var a = 0; a < st.files.length; a++) {
             var t = st.files[a];
             if (t.done && t.name) {
-                var tr = ebi('f{0}p'.format(t.n)).parentNode;
+                var tr = ebi('f' + t.n);
+                if (!tr)
+                    continue;
+
                 tr.parentNode.removeChild(tr);
                 t.name = undefined;
             }
@@ -460,7 +740,8 @@ function up2k_init(have_crypto) {
     function hashing_permitted() {
         if (multitask) {
             var ahead = st.bytes.hashed - st.bytes.uploaded;
-            return ahead < 1024 * 1024 * 128;
+            return ahead < 1024 * 1024 * 128 &&
+                st.todo.handshake.length + st.busy.handshake.length < 16;
         }
         return handshakes_permitted() && 0 ==
             st.todo.handshake.length +
@@ -524,7 +805,7 @@ function up2k_init(have_crypto) {
 
                 if (st.todo.handshake.length > 0 &&
                     st.busy.handshake.length == 0 && (
-                        st.todo.handshake[0].t3 || (
+                        st.todo.handshake[0].t4 || (
                             handshakes_permitted() &&
                             st.busy.upload.length < parallel_uploads
                         )
@@ -693,13 +974,8 @@ function up2k_init(have_crypto) {
         if (!need_filereader_cache)
             subchunks = 1;
 
-        var pb_html = '';
-        var pb_perc = 99.9 / nchunks;
-        for (var a = 0; a < nchunks; a++)
-            pb_html += '<div id="f{0}p{1}" style="width:{2}%"><div></div></div>'.format(
-                t.n, a, pb_perc);
-
-        ebi('f{0}p'.format(t.n)).innerHTML = pb_html;
+        pvis.setab(t.n, nchunks);
+        pvis.move(t.n, 'bz');
 
         var reader = new FileReader();
 
@@ -717,8 +993,6 @@ function up2k_init(have_crypto) {
 
             reader.readAsArrayBuffer(
                 bobslice.call(t.fobj, car, cdr));
-
-            prog(t.n, nchunk, col_hashing);
         };
 
         var segm_load = function (e) {
@@ -762,9 +1036,8 @@ function up2k_init(have_crypto) {
             var b64str = buf2b64(hslice).replace(/=$/, '');
             t.hash.push(b64str);
 
-            prog(t.n, nchunk, col_hashed);
+            pvis.hashed(t);
             if (++nchunk < nchunks) {
-                prog(t.n, nchunk, col_hashing);
                 return segm_next();
             }
 
@@ -774,13 +1047,14 @@ function up2k_init(have_crypto) {
                 alert('{0} ms, {1} MB/s\n'.format(t.t2 - t.t1, spd.toFixed(3)) + t.hash.join('\n'));
             }
 
-            ebi('f{0}t'.format(t.n)).innerHTML = 'connecting';
+            pvis.seth(t.n, 2, 'hashing done');
+            pvis.seth(t.n, 1, '📦 wait');
             st.busy.hash.splice(st.busy.hash.indexOf(t), 1);
             st.todo.handshake.push(t);
         };
 
         var segm_err = function () {
-            alert('y o u   b r o k e    i t\n\n(was that a folder? just files please)');
+            alert('y o u   b r o k e    i t\nerror: ' + reader.error);
         };
 
         segm_next();
@@ -810,7 +1084,7 @@ function up2k_init(have_crypto) {
                     else {
                         smsg = 'found';
                         var hit = response.hits[0],
-                            msg = linksplit(hit.rp).join(''),
+                            msg = linksplit(esc(hit.rp)).join(''),
                             tr = unix2iso(hit.ts),
                             tu = unix2iso(t.lmod),
                             diff = parseInt(t.lmod) - parseInt(hit.ts),
@@ -819,8 +1093,9 @@ function up2k_init(have_crypto) {
 
                         msg += '<br /><small>' + tr + ' (srv), ' + tu + ' (You), ' + sdiff + '</span></span>';
                     }
-                    ebi('f{0}p'.format(t.n)).innerHTML = msg;
-                    ebi('f{0}t'.format(t.n)).innerHTML = smsg;
+                    pvis.seth(t.n, 2, msg);
+                    pvis.seth(t.n, 1, smsg);
+                    pvis.move(t.n, smsg == '404' ? 'ng' : 'ok');
                     st.busy.handshake.splice(st.busy.handshake.indexOf(t), 1);
                     st.bytes.uploaded += t.size;
                     t.done = true;
@@ -831,7 +1106,15 @@ function up2k_init(have_crypto) {
                 if (response.name !== t.name) {
                     // file exists; server renamed us
                     t.name = response.name;
-                    ebi('f{0}n'.format(t.n)).innerHTML = linksplit(esc(t.purl + t.name)).join(' ');
+                    pvis.seth(t.n, 0, linksplit(esc(t.purl + t.name)).join(' '));
+                }
+
+                var chunksize = get_chunksize(t.size);
+                var cdr_idx = Math.ceil(t.size / chunksize) - 1;
+                var cdr_sz = (t.size % chunksize) || chunksize;
+                var cbd = [];
+                for (var a = 0; a <= cdr_idx; a++) {
+                    cbd.push(a == cdr_idx ? cdr_sz : chunksize);
                 }
 
                 t.postlist = [];
@@ -844,10 +1127,11 @@ function up2k_init(have_crypto) {
                             missing[a], JSON.stringify(t)));
 
                     t.postlist.push(idx);
+                    cbd[idx] = 0;
                 }
-                for (var a = 0; a < t.hash.length; a++)
-                    prog(t.n, a, (t.postlist.indexOf(a) == -1)
-                        ? col_uploaded : col_hashed);
+
+                pvis.setat(t.n, cbd);
+                pvis.prog(t, 0, cbd[0]);
 
                 var done = true;
                 var msg = '&#x1f3b7;&#x1f41b;';
@@ -861,49 +1145,56 @@ function up2k_init(have_crypto) {
                     msg = 'uploading';
                     done = false;
                 }
-                ebi('f{0}t'.format(t.n)).innerHTML = msg;
+                pvis.seth(t.n, 1, msg);
                 st.busy.handshake.splice(st.busy.handshake.indexOf(t), 1);
 
                 if (done) {
                     t.done = true;
                     st.bytes.uploaded += t.size - t.bytes_uploaded;
                     var spd1 = (t.size / ((t.t2 - t.t1) / 1000.)) / (1024 * 1024.);
-                    var spd2 = (t.size / ((t.t3 - t.t2) / 1000.)) / (1024 * 1024.);
-                    ebi('f{0}p'.format(t.n)).innerHTML = 'hash {0}, up {1} MB/s'.format(
-                        spd1.toFixed(2), spd2.toFixed(2));
+                    var spd2 = (t.size / ((t.t4 - t.t3) / 1000.)) / (1024 * 1024.);
+                    pvis.seth(t.n, 2, 'hash {0}, up {1} MB/s'.format(
+                        spd1.toFixed(2), spd2.toFixed(2)));
+                    pvis.move(t.n, 'ok');
                 }
-                else t.t3 = undefined;
+                else t.t4 = undefined;
 
                 tasker();
             }
             else {
-                var err = "";
-                var rsp = (xhr.responseText + '');
+                var err = "",
+                    rsp = (xhr.responseText + ''),
+                    ofs = rsp.lastIndexOf('\nURL: ');
+
+                if (ofs !== -1)
+                    rsp = rsp.slice(0, ofs);
+
+                if (rsp.indexOf('<pre>') === 0)
+                    rsp = rsp.slice(5);
+
+                st.bytes.uploaded += t.size;
                 if (rsp.indexOf('partial upload exists') !== -1 ||
                     rsp.indexOf('file already exists') !== -1) {
                     err = rsp;
-                    var ofs = err.lastIndexOf(' : ');
-                    if (ofs > 0)
-                        err = err.slice(0, ofs);
-
                     ofs = err.indexOf('\n/');
                     if (ofs !== -1) {
-                        err = err.slice(0, ofs + 1) + linksplit(err.slice(ofs + 2, -1)).join(' ');
+                        err = err.slice(0, ofs + 1) + linksplit(err.slice(ofs + 2)).join(' ');
                     }
                 }
                 if (err != "") {
-                    ebi('f{0}t'.format(t.n)).innerHTML = "ERROR";
-                    ebi('f{0}p'.format(t.n)).innerHTML = err;
+                    pvis.seth(t.n, 1, "ERROR");
+                    pvis.seth(t.n, 2, err);
+                    pvis.move(t.n, 'ng');
 
                     st.busy.handshake.splice(st.busy.handshake.indexOf(t), 1);
                     tasker();
                     return;
                 }
-                alert("server broke (error {0}):\n\"{1}\"\n".format(
-                    xhr.status,
-                    (xhr.response && xhr.response.err) ||
-                    (xhr.responseText && xhr.responseText) ||
-                    "no further information"));
+                alert("server broke; hs-err {0} on file [{1}]:\n".format(
+                    xhr.status, t.name) + (
+                        (xhr.response && xhr.response.err) ||
+                        (xhr.responseText && xhr.responseText) ||
+                        "no further information"));
             }
         };
 
@@ -933,7 +1224,7 @@ function up2k_init(have_crypto) {
         var npart = upt.npart;
         var t = st.files[upt.nfile];
 
-        prog(t.n, npart, col_uploading);
+        pvis.seth(t.n, 1, "🚀 send");
 
         var chunksize = get_chunksize(t.size);
         var car = npart * chunksize;
@@ -944,67 +1235,53 @@ function up2k_init(have_crypto) {
         var reader = new FileReader();
 
         reader.onerror = function () {
-            alert('y o u   b r o k e    i t\n\n(was that a folder? just files please)');
+            alert('y o u   b r o k e    i t\nerror: ' + reader.error);
         };
 
         reader.onload = function (e) {
             var xhr = new XMLHttpRequest();
             xhr.upload.onprogress = function (xev) {
-                var perc = xev.loaded / (cdr - car) * 100;
-                prog(t.n, npart, '', perc);
+                pvis.prog(t, npart, xev.loaded);
             };
             xhr.onload = function (xev) {
                 if (xhr.status == 200) {
-                    prog(t.n, npart, col_uploaded);
+                    pvis.prog(t, npart, cdr - car);
                     st.bytes.uploaded += cdr - car;
                     t.bytes_uploaded += cdr - car;
                     st.busy.upload.splice(st.busy.upload.indexOf(upt), 1);
                     t.postlist.splice(t.postlist.indexOf(npart), 1);
                     if (t.postlist.length == 0) {
-                        t.t3 = new Date().getTime();
-                        ebi('f{0}t'.format(t.n)).innerHTML = 'verifying';
+                        t.t4 = new Date().getTime();
+                        pvis.seth(t.n, 1, 'verifying');
                         st.todo.handshake.unshift(t);
                     }
                     tasker();
                 }
                 else
-                    alert("server broke (error {0}):\n\"{1}\"\n".format(
-                        xhr.status,
-                        (xhr.response && xhr.response.err) ||
-                        (xhr.responseText && xhr.responseText) ||
-                        "no further information"));
+                    alert("server broke; cu-err {0} on file [{1}]:\n".format(
+                        xhr.status, t.name) + (
+                            (xhr.response && xhr.response.err) ||
+                            (xhr.responseText && xhr.responseText) ||
+                            "no further information"));
             };
             xhr.open('POST', t.purl + 'chunkpit.php', true);
             //xhr.setRequestHeader("X-Up2k-Hash", t.hash[npart].substr(1) + "x");
             xhr.setRequestHeader("X-Up2k-Hash", t.hash[npart]);
             xhr.setRequestHeader("X-Up2k-Wark", t.wark);
             xhr.setRequestHeader('Content-Type', 'application/octet-stream');
-            xhr.overrideMimeType('Content-Type', 'application/octet-stream');
+            if (xhr.overrideMimeType)
+                xhr.overrideMimeType('Content-Type', 'application/octet-stream');
+
             xhr.responseType = 'text';
             xhr.send(e.target.result);
+
+            if (!t.t3)
+                t.t3 = new Date().getTime();
         };
 
         reader.readAsArrayBuffer(bobslice.call(t.fobj, car, cdr));
     }
 
-    /////
-    ////
-    ///   progress bar
-    //
-
-    function prog(nfile, nchunk, color, percent) {
-        var n1 = ebi('f{0}p{1}'.format(nfile, nchunk));
-        var n2 = n1.getElementsByTagName('div')[0];
-        if (percent === undefined) {
-            n1.style.background = color;
-            n2.style.display = 'none';
-        }
-        else {
-            n2.style.width = percent + '%';
-            n2.style.display = 'block';
-        }
-    }
-
     /////
     ////
     ///   config ui
@@ -1023,6 +1300,7 @@ function up2k_init(have_crypto) {
         if (btn.parentNode !== parent) {
             parent.appendChild(btn);
             ebi('u2conf').setAttribute('class', wide ? 'has_btn' : '');
+            ebi('u2cards').setAttribute('class', wide ? 'w' : '');
         }
     }
     window.addEventListener('resize', onresize);
@@ -1058,14 +1336,14 @@ function up2k_init(have_crypto) {
 
         var obj = ebi('nthread');
         if (dir.target) {
-            obj.style.background = '#922';
+            clmod(obj, 'err', 1);
             var v = Math.floor(parseInt(obj.value));
             if (v < 1 || v > 8 || v !== v)
                 return;
 
             parallel_uploads = v;
             swrite('nthread', v);
-            obj.style.background = '#444';
+            clmod(obj, 'err');
             return;
         }
 
